@@ -128,6 +128,7 @@ QString DataProxy::getBandNameFromFreq(const double _n)
     return QString();
 }
 
+
 double DataProxy::getLowLimitBandFromBandName(const QString _sm)
 {
     return -1.0;
@@ -434,6 +435,11 @@ int DataProxy::getQSOsAtHour(const int _hour, const int _log)
     return -1;
 }
 
+int DataProxy::getQSOsAtHourOnBand(const int _hour, const int _band ,const int _log)
+{
+    return -1;
+}
+
 int DataProxy::getQSOsOnMonth(const int _month, const int _log)
 {
     return -1;
@@ -720,6 +726,11 @@ QString DataProxy::getEntityNameFromId(const int _n)
     return QString();
 }
 
+int DataProxy::getEntityIdFromName(const QString _e)
+{
+    return -1;
+}
+
 QString DataProxy::getEntityMainPrefix(const int _entityN)
 {
     return QString();
