@@ -25,7 +25,7 @@
  *    along with KLog.  If not, see <http://www.gnu.org/licenses/>.          *
  *                                                                           *
  *****************************************************************************/
-//#include <QDebug>
+#include <QDebug>
 #include <QSqlRelationalTableModel>
 #include <QSqlQuery>
 #include <QSqlRecord>
