@@ -66,8 +66,7 @@
 #include "udpserver.h"
 #include "statisticswidget.h"
 #include "updatesatsdata.h"
-
-
+#include "hamlibclass.h"
 
 
 
@@ -155,14 +154,6 @@ private slots:
     void slotToolLoTWMarkAllQueued();
     void slotToolLoTWMarkAllYesThisLog();
     void slotToolLoTWMarkAllYes();
-    //void slotSearchExportButtonClicked();
-    //void slotSearchBoxSelectAllButtonClicked();
-    //void slotSearchClearButtonClicked();
-    //void slotSearchBoxSelectionChanged();
-    //void slotSearchBoxReSearchButtonClicked();
-
-    //void showMenuRightButtonSearchCreateActions();
-    //void righButtonSearchMenu(const int trow);
 
     void slotModeComboBoxChanged();
     void slotBandComboBoxChanged();
@@ -183,20 +174,6 @@ private slots:
 
     void slotSetup(const int _page=0);
 
-    //void slotQsoDeleteFromSearch();
-    //void slotQSLSentViaBureauFromSearch();
-    //void slotQSLSentViaDirectFromSearch();
-    //void slotQSLSentViaDirectMarkDXReqFromSearch();
-
-    //void slotQSLSentViaBureuMarkDXReqFromSearch();
-    //void slotQSLRecViaDirectFromSearch();
-    //void slotQSLRecViaBureauFromSearch();
-    //void slotQSLRecViaDirectMarkReqFromSearch();
-    //void slotQSLRecViaBureauMarkReqFromSearch();
-    //void slotQSLSentMarkAsRequested();
-    //void slotQSLRecMarkAsRequested();
-    //void slotQSOToEditFromSearch();
-
     void slotrstTXTextChanged();
     void slotrstRXTextChanged();
     void slotADIFExport();
@@ -209,15 +186,6 @@ private slots:
     //void slotQSLViaTextChanged();
     void slotTimeOutInfoBars(); // Clears the infoLabels when the timeout emits the signal
 
-
-//TODO: REMOVE EQSL
-    //void slotQSLRecvComboBoxChanged();
-    //void slotQSLSentComboBoxChanged();
-    //void sloteQSLRecvComboBoxChanged();
-    //void sloteQSLSentComboBoxChanged();
-    //void slotLotwRecvComboBoxChanged();
-    //void slotLotwSentComboBoxChanged();
-
     void slotSetPropMode(const QString _p);
     void slotFillEmptyDXCCInTheLog();
     void slotUpdateCTYDAT();
@@ -254,12 +222,6 @@ private slots:
 
     //SEARCH    
     void slotShowSearchWidget();                // The SearchWidget request being shown
-    //void slotDoubleClickSearch( QTreeWidgetItem* item, int); // Double click on a QSO in the search box
-    //void slotRighButtonSearch(const QPoint& pos);
-    //void slotToolSearchNeededQSLToSend();
-    //void slotToolSearchNeededQSLPendingToReceive();
-    //void slotToolSearchNeededQSLRequested();
-    //void slotToolSearchQSL(const int actionQSL);
     //SEARCH
 
     // CLUSTER
@@ -275,12 +237,17 @@ private slots:
     void slotShowSoftUpdateResults(const bool _b);   // Software Update: Receives the signal to see if it is needed or not to update
 
     //SATELLITE
-    void slotSatBandTXComboBoxChanged(const QString _q);
-
-    void slotDefineNewBands(const QStringList _bands);
+    //void slotSatBandTXComboBoxChanged(const QString _q);
+    void slotDefineNewBands (const QStringList _bands);
+    void slotSatTXFreqNeeded(const double _f);
+    void slotSatRXFreqNeeded(const double _f);
     void slotSatChangeRXFreq(const double _f);
     void slotSatChangeTXFreq(const double _f);
-	
+
+    //HAMLIB
+    void slotHamlibTXFreqChanged(const double _f);
+    void slotHamlibModeChanged(const QString _m);
+
     //DXCCWIDGET
     void slotShowQSOFromDXCCWidget(const int _q);
     void slotShowQSOsFromDXCCWidget(QList<int> _qsos);
@@ -298,10 +265,12 @@ private slots:
 
 private:
     bool maybeSave();
-
+    void updateBandComboBox(const QString _band);
     UpdateSatsData *updateSatsData;
     //UPDATE CTY.DAT
     DownLoadCTY *downloadcty;
+    HamLibClass *hamlib;
+    bool hamlibActive;
     //</UPDATE CTY.DAT>
 
     void createStatusBar();
@@ -366,6 +335,7 @@ private:
     void showDXMarathon(const int _year);
     void updateQSLRecAndSent();
     double checkFreqRanges(double _f);
+    void setRSTToMode(const QString _m);
 
     // CLUSTER
     void clusterSpotToLog(const QString _call, const QString _freq);
@@ -543,7 +513,8 @@ private:
     //bool searchSelectAllClicked, stationCallSignShownInSearch;
 
     bool checkNewVersions, reportInfo; // Selected in the Setup->Misc to check if new versions and report info back to KLog's servers
-
+    bool txFreqBeingChanged, rxFreqBeingChanged, updatingBands;            // When the freqs is being modified it is defined to true to prevent other automated to change.
+    bool txFreqBeingAutoChanged, rxFreqBeingAutoChanged;        // This is defined to true when freq is being changed by the Sat tab to prevent a loop.
     bool qslingNeeded;
     bool noMoreErrorShown;              // If true, the errors shown in slotQueryErrorManagement will not be shown anymore in that KLog execution
     bool noMoreModeErrorShown;          // If true, the non-valid modes received from WSJT-x will not be showed to the user
