@@ -30,11 +30,11 @@
 MainWindowInputComment::MainWindowInputComment(QWidget *parent) :
     QWidget(parent)
 {
-    //qDebug() << "MainWindowInputComment::MainWindowInputComment"   << endl;
+     //qDebug() << "MainWindowInputComment::MainWindowInputComment"   << endl;
     commentLineEdit = new QLineEdit();
     comment.clear();
     createUI();
-    //qDebug() << "MainWindowInputComment::MainWindowInputComment - END"   << endl;
+     //qDebug() << "MainWindowInputComment::MainWindowInputComment - END"   << endl;
 }
 
 
@@ -43,7 +43,7 @@ MainWindowInputComment::~MainWindowInputComment(){}
 void MainWindowInputComment::createUI()
 {
 
-    commentLineEdit->setToolTip(tr("Add a comment for this QSO"));
+    commentLineEdit->setToolTip(tr("Add a comment for this QSO."));
 
     QVBoxLayout *tabLayout = new QVBoxLayout;
     tabLayout->addWidget(commentLineEdit);
