@@ -30,7 +30,7 @@
 MainWindowInputOthers::MainWindowInputOthers(DataProxy *dp, QWidget *parent) :
     QWidget(parent)
 {
-    //qDebug() << "MainWindowInputOthers::MainWindowInputOthers" << endl;
+     //qDebug() << "MainWindowInputOthers::MainWindowInputOthers" << endl;
     entitiesList.clear();
     propModeList.clear();
 
@@ -51,14 +51,14 @@ MainWindowInputOthers::MainWindowInputOthers(DataProxy *dp, QWidget *parent) :
 
 
     createUI();
-    //qDebug() << "MainWindowInputOthers::MainWindowInputOthers - END" << endl;
+     //qDebug() << "MainWindowInputOthers::MainWindowInputOthers - END" << endl;
 }
 
 MainWindowInputOthers::~MainWindowInputOthers(){}
 
 void MainWindowInputOthers::createUI()
 {
-   //qDebug() << "MainWindowInputOthers::createUI" << endl;
+    //qDebug() << "MainWindowInputOthers::createUI" << endl;
 
     palRed.setColor(QPalette::Text, Qt::red);
     palBlack.setColor(QPalette::Text, Qt::black);
@@ -75,12 +75,12 @@ void MainWindowInputOthers::createUI()
     entityNameLabel->setAlignment(Qt::AlignVCenter| Qt::AlignRight);
     propModeLabel->setAlignment(Qt::AlignVCenter| Qt::AlignRight);
 
-    entityPrimDivComboBox->setToolTip(tr("Select the primary division for this QSO"));
-    entitySecDivComboBox->setToolTip(tr("Select the secondary division for this QSO"));
-    entityNameComboBox->setToolTip(tr("Select the entity for this QSO"));
-    propModeComboBox->setToolTip(tr("Select the propagation mode for this QSO"));
-    iotaContinentComboBox->setToolTip(tr("Select the IOTA continent for this QSO"));
-    iotaNumberLineEdit->setToolTip(tr("Select the IOTA reference number for this QSO"));
+    entityPrimDivComboBox->setToolTip(tr("Select the primary division for this QSO."));
+    entitySecDivComboBox->setToolTip(tr("Select the secondary division for this QSO."));
+    entityNameComboBox->setToolTip(tr("Select the entity for this QSO."));
+    propModeComboBox->setToolTip(tr("Select the propagation mode for this QSO."));
+    iotaContinentComboBox->setToolTip(tr("Select the IOTA continent for this QSO."));
+    iotaNumberLineEdit->setToolTip(tr("Select the IOTA reference number for this QSO."));
 
     entityPrimDivComboBox->setEnabled(false);
     entitySecDivComboBox->setEnabled(false);
@@ -133,7 +133,7 @@ void MainWindowInputOthers::createUI()
 
 void MainWindowInputOthers::clear()
 {
-   //qDebug() << "MainWindowInputOthers::clear" << endl;
+    //qDebug() << "MainWindowInputOthers::clear" << endl;
     entityNameComboBox->setCurrentIndex(0);
     propModeComboBox->setCurrentIndex(0);
     iotaContinentComboBox->setCurrentIndex(0);
@@ -142,7 +142,7 @@ void MainWindowInputOthers::clear()
 
 void MainWindowInputOthers::setEntitiesList(const QStringList _qs)
 {
-   //qDebug() << "MainWindowInputOthers::setEntitiesList: " << QString::number(_qs.length()) << endl;
+    //qDebug() << "MainWindowInputOthers::setEntitiesList: " << QString::number(_qs.length()) << endl;
     entitiesList.clear();
     entitiesList << _qs;
     if (entitiesList.size()>1)
@@ -155,7 +155,7 @@ void MainWindowInputOthers::setEntitiesList(const QStringList _qs)
 
 void MainWindowInputOthers::setEntity(const int _ent)
 {// Select the appropriate entity in the ComboBox
-    //qDebug() << "MainWindowInputOthers::setEntity: " << QString::number(_ent) << endl;
+     //qDebug() << "MainWindowInputOthers::setEntity: " << QString::number(_ent) << endl;
     if (_ent<=0)
     {
         entityNameComboBox->setCurrentIndex(0);
@@ -174,11 +174,11 @@ void MainWindowInputOthers::setEntity(const int _ent)
     pref = dataProxy->getEntityNameFromId(_ent);
 
     //int indexC = entityNameComboBox->findText(pref, Qt::MatchContains);
-    //qDebug() << "MainWindow::selectCorrectEntity: aux to the findText: " << aux << endl;
+     //qDebug() << "MainWindow::selectCorrectEntity: aux to the findText: " << aux << endl;
     //int indexC = entityNameComboBox->findText("(" + aux + ")", Qt::MatchContains);
     int indexC = entityNameComboBox->findText("(" + aux + ")", Qt::MatchEndsWith);
 
-    //qDebug() << "MainWindow::selectCorrectEntity: " << pref << "/" << QString::number(indexC) << endl;
+     //qDebug() << "MainWindow::selectCorrectEntity: " << pref << "/" << QString::number(indexC) << endl;
     entityNameComboBox->setCurrentIndex(indexC);
     setIOTAContinentFromEntity(_ent);
 
@@ -186,15 +186,14 @@ void MainWindowInputOthers::setEntity(const int _ent)
 
 QString MainWindowInputOthers::getEntityPrefix()
 {
-   //qDebug() << "MainWindowInputOthers::getEntityName" << endl;
+    //qDebug() << "MainWindowInputOthers::getEntityName" << endl;
     return (entityNameComboBox->currentText()).split('-').at(0);
-    //qDebug() << "MainWindowInputOthers::getEntity: " << pref << "/" << QString::number(world->getQRZARRLId(pref))<< endl;
     //return world->getQRZARRLId(pref);
 }
 
 void MainWindowInputOthers::setPropMode(const QString _qs)
 {
-   //qDebug() << "MainWindowInputOthers::setPropMode: " << _qs << endl;
+    //qDebug() << "MainWindowInputOthers::setPropMode: " << _qs << endl;
     if(( propModeComboBox->findText(_qs+" -", Qt::MatchContains))>0)
     {
         propModeComboBox->setCurrentIndex( propModeComboBox->findText(_qs+" -", Qt::MatchContains));
@@ -208,9 +207,9 @@ void MainWindowInputOthers::setPropMode(const QString _qs)
 QString MainWindowInputOthers::getPropModeFromComboBox()
 {
     QString _pm = QString();
-  //qDebug() << "MainWindow::getPropModeFromComboBox:" << propModeComboBox->currentText() << endl;
+   //qDebug() << "MainWindow::getPropModeFromComboBox:" << propModeComboBox->currentText() << endl;
     _pm = (((propModeComboBox->currentText()).split('-')).at(1)).simplified();
-  //qDebug() << "MainWindow::getPropModeFromComboBox: " << _pm << endl;
+   //qDebug() << "MainWindow::getPropModeFromComboBox: " << _pm << endl;
     if (_pm == "Not")
     {
         return QString();
@@ -242,7 +241,7 @@ void MainWindowInputOthers::setIOTA(const QString _qs, const bool _black)
 {//TODO: Seems to be better to send the color info like in: (it is much more flexible as I can send any color!)
 
     //void MainWindowInputQSL::setQSLVia(const QString _qs, QColor qColor)
-   //qDebug() << "MainWindow::setIOTA: " << _qs << endl;
+    //qDebug() << "MainWindow::setIOTA: " << _qs << endl;
     if ( (checkIfValidIOTA(_qs)).length() !=6 )
     {
         return;
@@ -250,7 +249,7 @@ void MainWindowInputOthers::setIOTA(const QString _qs, const bool _black)
     else
     {
         QStringList values = _qs.split("-", QString::SkipEmptyParts);
-       //qDebug() << "MainWindowInputOthers::setIOTA: IOTA " << _qs << endl;
+        //qDebug() << "MainWindowInputOthers::setIOTA: IOTA " << _qs << endl;
         iotaContinentComboBox->setCurrentIndex( iotaContinentComboBox->findText(values.at(0) ) );
         iotaNumberLineEdit->setText(values.at(1));
     }
@@ -272,22 +271,22 @@ QString MainWindowInputOthers::getIOTA()
 
 void MainWindowInputOthers::setIOTAContinentFromEntity(const int _n)
 {
-   //qDebug() << "MainWindow::setIOTAContinentFromEntity:" << QString::number(_n) << endl;
+    //qDebug() << "MainWindow::setIOTAContinentFromEntity:" << QString::number(_n) << endl;
     setIOTAContinent(dataProxy->getContinentShortNameFromEntity(_n)) ;
 }
 
 void MainWindowInputOthers::setIOTAContinent(const QString _qs)
 {
-    //qDebug() << "MainWindowInputOthers::setIOTAContinent: " << _qs << endl;
-    //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index(a): " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << endl;
+     //qDebug() << "MainWindowInputOthers::setIOTAContinent: " << _qs << endl;
+     //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index(a): " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << endl;
     if(( iotaContinentComboBox->findText(_qs, Qt::MatchContains))>0)
     {
-       //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << endl;
+        //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: " << QString::number(iotaContinentComboBox->findText(_qs, Qt::MatchContains)) << endl;
         iotaContinentComboBox->setCurrentIndex( iotaContinentComboBox->findText(_qs, Qt::MatchContains));
     }
     else
     {
-        //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: 00" << endl;
+         //qDebug() << "MainWindowInputOthers::setIOTAContinent: setting to index: 00" << endl;
         iotaContinentComboBox->setCurrentIndex(0);
     }
 }
@@ -307,7 +306,7 @@ QString MainWindowInputOthers::checkIfValidIOTA(const QString _tiota)
 Returns a valid format IOTA if possible and "" in other cases.
 
 ************************************/
-   //qDebug() << "MainWindowInputOthers::checkIfValidIOTA: " << _tiota << endl;
+    //qDebug() << "MainWindowInputOthers::checkIfValidIOTA: " << _tiota << endl;
     //bool _valid = false;
     QString _continent;
     QString _number;
@@ -323,8 +322,8 @@ Returns a valid format IOTA if possible and "" in other cases.
         return "";
     }
 
-   //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (cont) " << _continent << endl;
-   //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (numb): " << _number << endl;
+    //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (cont) " << _continent << endl;
+    //qDebug() << "MainWindowInputOthers::checkIfValidIOTA (numb): " << _number << endl;
 
     // Check if continent is valid
 
