@@ -40,8 +40,7 @@ MainWindowSatTab::MainWindowSatTab(DataProxy *dp, QWidget *parent) :
     satBandTXComboBox = new QComboBox;
     satBandRXComboBox = new QComboBox;
     txFreqSpinBox = new QDoubleSpinBox;
-    rxFreqSpinBox = new QDoubleSpinBox;
-
+    rxFreqSpinBox = new QDoubleSpinBox;    
 
     keepThisDataForNextQSORadiobutton = new QRadioButton;
 
@@ -50,8 +49,16 @@ MainWindowSatTab::MainWindowSatTab(DataProxy *dp, QWidget *parent) :
 
     createUI();
     populateSatComboBox();
+    //txBandBeingChanged = false;
+    //rxBandBeingChanged = false;
+    txFreqBeingAutoChanged = false;
+    rxFreqBeingAutoChanged = false;
+    //txBandsBeingChanged = false;
+    updatingBands = false;
     satNameLineEdit->setEnabled(false);
     satOtherLabel->setEnabled(false);
+    palRed.setColor(QPalette::Text, Qt::red);
+    palBlack.setColor(QPalette::Text, Qt::black);
 
     setDefaultBands(); //TODO: Check how the bands are included not to create an inconsistence with the selected (in the setup) bands
      //qDebug() << "MainWindowSatTab::MainWindowSatTab - END"   << endl;
@@ -68,8 +75,6 @@ void MainWindowSatTab::createUI()
     connect(satBandRXComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotSatBandRXComboBoxChanged()) ) ;
     connect(satBandTXComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotSatBandTXComboBoxChanged()) ) ;
 
-
-
     connect(txFreqSpinBox, SIGNAL(valueChanged(double)), this, SLOT(slotSatFreqTXChanged()) ) ;
     connect(rxFreqSpinBox, SIGNAL(valueChanged(double)), this, SLOT(slotSatFreqRXChanged()) ) ;
 
@@ -119,11 +124,11 @@ void MainWindowSatTab::createUI()
 
 
     txFreqSpinBox->setDecimals(3);
-    txFreqSpinBox->setMaximum(9999);
+    txFreqSpinBox->setMaximum(99999);
     txFreqSpinBox->setSuffix(" " + tr("MHz"));
 
     rxFreqSpinBox->setDecimals(3);
-    rxFreqSpinBox->setMaximum(9999);
+    rxFreqSpinBox->setMaximum(99999);
     rxFreqSpinBox->setSuffix(" " + tr("MHz"));
 
 
@@ -211,7 +216,6 @@ void MainWindowSatTab::slotSatNameTextChanged()
 
 }
 
-
 void MainWindowSatTab::slotSatModeTextChanged()
 {
     //qDebug() << "MainWindowSatTab::slotSatModeTextChanged: " << satModeLineEdit->text() << endl;
@@ -360,6 +364,7 @@ void MainWindowSatTab::clear()
     }
 
 }
+
 void MainWindowSatTab::refreshData()
 {
     populateSatComboBox();
@@ -440,15 +445,22 @@ int MainWindowSatTab::getSatIndex(const QString _p)
     return satNameComboBox->findText(_p, Qt::MatchContains);
 }
 
-
 void MainWindowSatTab::addBands(QStringList _bands)
 {
-     //qDebug() << "MainWindowSatTab::addBands: " << QString::number(_bands.length()) << endl;
+    //qDebug() << "MainWindowSatTab::addBands: " << QString::number(_bands.length()) << endl;
+    updatingBands = true;
+    QString _txBand = satBandTXComboBox->currentText();
+    QString _rxBand = satBandRXComboBox->currentText();
+    //txBandsBeingChanged = true;
     satBandRXComboBox->clear();
     satBandTXComboBox->clear();
     satBandTXComboBox->addItems(_bands);
     satBandRXComboBox->addItems(_bands);
-
+    satBandTXComboBox->setCurrentIndex(satBandTXComboBox->findText(_txBand, Qt::MatchCaseSensitive));
+    satBandRXComboBox->setCurrentIndex(satBandRXComboBox->findText(_rxBand, Qt::MatchCaseSensitive));
+    //txBandsBeingChanged = false;
+    updatingBands = false;
+    //qDebug() << "MainWindowSatTab::addBands - END"  << endl;
 }
 
 void MainWindowSatTab::setDefaultBands()
@@ -463,49 +475,105 @@ void MainWindowSatTab::setDefaultBands()
 
 }
 
-
 void MainWindowSatTab::slotSatBandRXComboBoxChanged()
 {
-     //qDebug() << "MainWindowsatTab::slotSatBandRXComboBoxChanged" << endl;
-    emit satBandRXChanged(satBandRXComboBox->currentText());
+    //qDebug() << "MainWindowsatTab::slotSatBandRXComboBoxChanged" << endl;
+    if (updatingBands)
+    {
+        return;
+    }
+    bool freqInBand = dataProxy->isThisFreqInBand(satBandRXComboBox->currentText(), QString::number(rxFreqSpinBox->value()));
+    if(!freqInBand)
+    { // If the freq does not belong to the current band, we need to update the band
+        rxFreqSpinBox->setValue(dataProxy->getLowLimitBandFromBandName(satBandRXComboBox->currentText()));
+    }
+    //qDebug() << "MainWindowsatTab::slotSatBandRXComboBoxChanged-END" << endl;
 
 }
 
-void MainWindowSatTab::slotSatBandTXComboBoxChanged()
-{
-     //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged" << endl;
-    emit satBandTXChanged(satBandTXComboBox->currentText());
-}
-
 void MainWindowSatTab::slotSatFreqRXChanged()
 {
-    QString _q;
-    int v = dataProxy->getBandIdFromFreq(rxFreqSpinBox->value());
-    if (v<0)
+    //qDebug() << "MainWindowsatTab::slotSatFreqRXChanged: " << QString::number(rxFreqSpinBox->value()) << endl;
+
+    int bandId = dataProxy->getBandIdFromFreq(rxFreqSpinBox->value());
+    if (bandId<1)
+    { //This prevent that a non-hamradio frequency is used on TX
+        //qDebug() << "MainWindowsatTab::slotSatFreqRXChanged: Not in band, exiting... " << endl;
+        rxFreqSpinBox->setToolTip(tr("RX Frequency in MHz.\nFrequency is not in a hamradio band!"));
+        rxFreqSpinBox->setPalette(palRed);
+    }
+    else
+    {
+        rxFreqSpinBox->setToolTip(tr("RX Frequency in MHz."));
+        rxFreqSpinBox->setPalette(palBlack);
+        bool freqInBand = dataProxy->isThisFreqInBand(satBandRXComboBox->currentText(), QString::number(rxFreqSpinBox->value()));
+        if(!freqInBand)
+        { // If the freq does not belong to the current band, we need to update the band
+            satBandRXComboBox->setCurrentIndex(satBandRXComboBox->findText(dataProxy->getBandNameFromFreq(rxFreqSpinBox->value()), Qt::MatchCaseSensitive));
+
+        }
+
+    }
+
+    if (!rxFreqBeingAutoChanged)
+    {
+        emit satRxFreqChanged(rxFreqSpinBox->value());
+    }
+
+    //qDebug() << "MainWindowsatTab::slotSatFreqRXChanged-END" << endl;
+}
+
+void MainWindowSatTab::slotSatBandTXComboBoxChanged()
+{
+    //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged:"  << endl;
+    if (updatingBands)
     {
         return;
     }
-
-    _q = dataProxy->getNameFromBandId (v);
-
-    satBandRXComboBox->setCurrentIndex(satBandRXComboBox->findText(_q));
+    bool freqInBand = dataProxy->isThisFreqInBand(satBandTXComboBox->currentText(), QString::number(txFreqSpinBox->value()));
+    if(!freqInBand)
+    { // If the freq does not belong to the current band, we need to update the band
+        txFreqSpinBox->setValue(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()));
+        //setUpLinkFreq(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()));
+    }
+    //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged-END" << endl;
 
 }
+
 void MainWindowSatTab::slotSatFreqTXChanged()
 {
-     //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged" << endl;
+    //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: " << QString::number(txFreqSpinBox->value()) << endl;
+    // user changes TX Freq
+    // If band is real and band is configured, bandcombo is selected
+    // If band is real and not configured, we launch the band config and select the band.
+    // if band is real emit the band
 
-    QString _q;
-    int v = dataProxy->getBandIdFromFreq(txFreqSpinBox->value());
-    if (v<0)
+    int bandId = dataProxy->getBandIdFromFreq(txFreqSpinBox->value());
+    if (bandId<1)
+    { //This prevent that a non-hamradio frequency is used on TX
+        //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: Not in band, exiting... " << endl;
+        txFreqSpinBox->setToolTip(tr("TX Frequency in MHz.\nFrequency is not in a hamradio band!"));
+        txFreqSpinBox->setPalette(palRed);
+    }
+    else
     {
-        return;
+        txFreqSpinBox->setToolTip(tr("TX Frequency in MHz."));
+        txFreqSpinBox->setPalette(palBlack);
+        bool freqInBand = dataProxy->isThisFreqInBand(satBandTXComboBox->currentText(), QString::number(txFreqSpinBox->value()));
+        if(!freqInBand)
+        { // If the freq does not belong to the current band, we need to update the band
+            satBandTXComboBox->setCurrentIndex(satBandTXComboBox->findText(dataProxy->getBandNameFromFreq(txFreqSpinBox->value()), Qt::MatchCaseSensitive));
+            //setUpLinkFreq(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()));
+        }
+
     }
 
-    _q = dataProxy->getNameFromBandId (v);
-
-    satBandTXComboBox->setCurrentIndex(satBandTXComboBox->findText(_q));
+    if (!txFreqBeingAutoChanged)
+    {
+        emit satTxFreqChanged(txFreqSpinBox->value());
+    }
 
+    //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged-END" << endl;
 }
 
 void MainWindowSatTab::setUpLink(const QString _t)
@@ -545,17 +613,32 @@ void MainWindowSatTab::setUpLink(const QString _t)
 
 void MainWindowSatTab::setUpLinkFreq(const double _t)
 {
-   //qDebug) << "MainWindowsatTab::setUpLinkFreq: " << QString::number(_t) << endl;
-    if ((dataProxy->getBandIdFromFreq(_t))>0)
-    {
-        txFreqSpinBox->setValue(_t);
-    }
+    //qDebug() << "MainWindowsatTab::setUpLinkFreq: " << QString::number(_t) << endl;
+
+    txFreqBeingAutoChanged = true;
+
+    txFreqSpinBox->setValue(_t);
+
+    txFreqBeingAutoChanged = false;
+    //qDebug() << "MainWindowsatTab::setUpLinkFreq END" << endl;
+}
+
+void MainWindowSatTab::setDownLinkFreq(const double _t)
+{
+    //qDebug() << "MainWindowsatTab::setDownLinkFreq: " << QString::number(_t) << endl;
+    rxFreqBeingAutoChanged = true;
+    rxFreqSpinBox->setValue(_t);
+    rxFreqBeingAutoChanged = false;
+
+    //qDebug() << "MainWindowsatTab::setDownLinkFreq END" << endl;
 }
 
 void MainWindowSatTab::setBandsOfSat(const QString _p)
 {
     // Until the data is in the DB, this function tries to solve data of active sats from: http://www.amsat.org/status/
-     //qDebug() << "MainWindowSatTab::setBandsOfSat: " << _p << " - Short: " << _p.section(' ', 0, 0) << endl;
+    // This functio:
+    //  - identifies the freqs & bands that the sat is using
+    //qDebug() << "MainWindowSatTab::setBandsOfSat: " << _p << " - Short: " << _p.section(' ', 0, 0) << endl;
     //"AO-7 - AMSAT-OSCAT 7"
     //2M/10M << 2M/70CM
 
@@ -566,35 +649,37 @@ void MainWindowSatTab::setBandsOfSat(const QString _p)
     double downLink = 0.0;
     downLink = (dataProxy->getSatelliteDownlink(_p.section(' ', 0, 0))).toDouble();
 
-     //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: " << upLink << endl;
-
-    emit satTxFreqChanged(upLink);
-    txFreqSpinBox->setValue(upLink);
+    //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: " << QString::number(upLink)<< endl;
 
 
     if (upLink>0)
     {
-        QString upLinkBand = dataProxy->getBandNameFromFreq(upLink);
+        //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: emitting: " << QString::number(upLink)<< endl;
+        emit satTXFreqNeeded(upLink);
+        //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: emitted: " << QString::number(upLink)<< endl;
 
-        int indexTX = satBandTXComboBox->findText(upLinkBand, Qt::MatchCaseSensitive);
-        if (indexTX>0)
-        {
-            satBandTXComboBox->setCurrentIndex(indexTX);
-        }
-        else
-        {
-            addNewBand(upLinkBand);
-            indexTX = satBandTXComboBox->findText(upLinkBand, Qt::MatchCaseSensitive);
-            satBandTXComboBox->setCurrentIndex(indexTX);
-        }
     }
     else
     {
         satBandTXComboBox->setCurrentIndex(0);
     }
 
+    if (downLink>0)
+    {
+        //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: emitting: " << QString::number(downLink)<< endl;
+        emit satRXFreqNeeded(downLink);
+        //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: emitted: " << QString::number(downLink)<< endl;
 
-    emit satRxFreqChanged(downLink);
+    }
+    else
+    {
+        satBandRXComboBox->setCurrentIndex(0);
+    }
+    //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: emiting: " << QString::number(downLink)<< endl;
+    //emit satRxFreqChanged(downLink);
+
+    /*
+    emit satRXFreqNeeded(downLink);
     rxFreqSpinBox->setValue(downLink);
 
     if (downLink>0)
@@ -619,7 +704,8 @@ void MainWindowSatTab::setBandsOfSat(const QString _p)
     {
         satBandRXComboBox->setCurrentIndex(0);
     }
-
+    */
+    //qDebug() << "MainWindowSatTab::setBandsOfSat: " << _p << " - END "  << endl;
 }
 
 void MainWindowSatTab::addNewBand(const QString _p)
