@@ -54,8 +54,10 @@ public:
     void addBands(QStringList _bands);
     void setDefaultBands(); //Defines the default bands for SAT communications: 10m/2m/70cm/23CM only if they exist on the selected bands
 
-    void setUpLink(const QString _t);
+
     void setUpLinkFreq(const double _t);
+    void setDownLinkFreq(const double _t);
+
     void setLocator(const QString _t);
     void refreshData();
 
@@ -63,11 +65,13 @@ public:
 
 signals:
     void setPropModeSat(const QString _p);
-    void satBandTXChanged(const QString _p);
-    void satBandRXChanged(const QString _p);
+    //void satBandTXChanged(const QString _p);
+    //void satBandRXChanged(const QString _p);
     void newBandsToBeAdded(const QStringList _p);
     void satTxFreqChanged(const double _p);
     void satRxFreqChanged(const double _p);
+    void satTXFreqNeeded(const double _p);
+    void satRXFreqNeeded(const double _p);
     void dxLocatorChanged(const QString _p);
 
 private slots:
@@ -87,6 +91,7 @@ private:
     int getSatIndex(const QString _p);
     void setBandsOfSat(const QString _p);
     void addNewBand(const QString _p);
+    void setUpLink(const QString _t);
 
     QLineEdit *satNameLineEdit;
     QLineEdit *satModeLineEdit;
@@ -100,6 +105,8 @@ private:
     QComboBox *satBandTXComboBox, *satBandRXComboBox;
     QStringList satNames, satModes;
     QStringList satellitesList;
+    bool txFreqBeingAutoChanged, rxFreqBeingAutoChanged, updatingBands;
+    QPalette palRed, palBlack; // To paint Text in red or black(normal)
 
     QDoubleSpinBox *txFreqSpinBox, *rxFreqSpinBox;
     DataProxy *dataProxy;
