@@ -34,7 +34,7 @@ This class calls all the othet "Setup..." to manage the configuration
 
 SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
 {
-     //qDebug() << "SetupDialog::SetupDialog 1" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 1" << endl;
     util = new Utilities;
     constrid = 1;
     nolog = true;
@@ -62,8 +62,8 @@ SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
     //qDebug() << "SetupDialog::SetupDialog 3.3" << endl;
     tabWidget = new QTabWidget;
     //qDebug() << "SetupDialog::SetupDialog 3.4" << endl;
-
-
+    hamlibPage = new SetupPageHamLib(dataProxy, this);
+    //qDebug() << "SetupDialog::SetupDialog 3.4.1" << endl;
     userDataPage = new SetupPageUserDataPage(dataProxy);
     //qDebug() << "SetupDialog::SetupDialog 3.5" << endl;
     bandModePage = new SetupPageBandMode(dataProxy, this);
@@ -83,6 +83,7 @@ SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
     UDPPage = new SetupPageUDP(this);    
     //qDebug() << "SetupDialog::SetupDialog 3.13" << endl;
     satsPage = new SetupPageSats(dataProxy, this);
+    //hamlibPage = new SetupPageHamLib(dataProxy, this);
 
     //qDebug() << "SetupDialog::SetupDialog 4" << endl;
 
@@ -96,6 +97,7 @@ SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
     tabWidget->addTab(clubLogPage, "ClubLog");
     tabWidget->addTab(UDPPage, "WSJT-X");
     tabWidget->addTab(satsPage , tr("Satellites"));
+    tabWidget->addTab(hamlibPage, tr ("HamLib"));
 
 
     QPushButton *closeButton = new QPushButton(tr("Cancel"));
@@ -137,7 +139,7 @@ SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
 
 SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
 {
-     //qDebug() << "SetupDialog::SetupDialog 2" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 2" << endl;
     constrid = 2;
     util = new Utilities;
     firstTime = _firstTime;
@@ -162,8 +164,10 @@ SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString
     clubLogPage = new SetupPageClubLog(this);
     UDPPage = new SetupPageUDP(this);
     satsPage = new SetupPageSats(dataProxy, this);
+    hamlibPage = new SetupPageHamLib(dataProxy, this);
 
-     //qDebug() << "SetupDialog::SetupDialog 02" << endl;
+
+    //qDebug() << "SetupDialog::SetupDialog 02" << endl;
     tabWidget->addTab(userDataPage, tr("User data"));
     tabWidget->addTab(bandModePage, tr("Bands/Modes"));
     tabWidget->addTab(dxClusterPage, tr("D&X-Cluster"));
@@ -174,6 +178,7 @@ SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString
     tabWidget->addTab(clubLogPage, tr("ClubLog"));
     tabWidget->addTab(UDPPage, tr("WSJT-X"));
     tabWidget->addTab(satsPage , tr("Satellites"));
+    tabWidget->addTab(hamlibPage, tr ("HamLib"));
 
      //qDebug() << "SetupDialog::SetupDialog 03" << endl;
 
@@ -192,16 +197,16 @@ SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString
     mainLayout->addLayout(horizontalLayout);
     mainLayout->addLayout(buttonsLayout);
 
-     //qDebug() << "SetupDialog::SetupDialog 04" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 04" << endl;
 
     setLayout(mainLayout);
 
     setWindowTitle(tr("Config Dialog"));
 
-     //qDebug() << "SetupDialog::SetupDialog 05" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 05" << endl;
 
     slotReadConfigData();
-     //qDebug() << "SetupDialog::SetupDialog 05.1" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 05.1" << endl;
 
     if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
     {
@@ -215,7 +220,7 @@ SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString
     connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
     connectActions();
 
-     //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
 }
 
 
@@ -580,6 +585,12 @@ void SetupDialog::slotOkButtonClicked()
         stream << "RealTimeFromWSJTX=" << UDPPage->getReaDataFromWSJTx() << ";" <<  endl;
         stream << "InfoTimeOut=" << UDPPage->getTimeout() << ";" <<  endl;
 
+        //qDebug() << "SetupDialog::slotOkButtonClicked: hamlib" << endl;
+        QString _aa = hamlibPage->getData();
+        stream << _aa << endl;
+
+        //qDebug() << "SetupDialog::slotOkButtonClicked: hamlib-2: " << _aa << endl;
+
         //WSJTX
 
         file.close ();
@@ -592,7 +603,7 @@ void SetupDialog::slotOkButtonClicked()
 
 void SetupDialog::slotReadConfigData()
 {
-     //qDebug() << "SetupDialog::slotReadConfigData" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData" << endl;
     if (firstTime)
     {
         setDefaults();
@@ -602,7 +613,7 @@ void SetupDialog::slotReadConfigData()
         bandModePage->setActiveBands(bands);
     }
 
-         //qDebug() << "SetupDialog::slotReadConfigData - 1" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData - 1" << endl;
 
     QFile file(configFileName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
@@ -610,7 +621,7 @@ void SetupDialog::slotReadConfigData()
         //firstTime = true;
         return;
     }
-     //qDebug() << "SetupDialog::slotReadConfigData - 2" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData - 2" << endl;
     //dxClusterServers.clear();
 
 
@@ -620,7 +631,7 @@ void SetupDialog::slotReadConfigData()
         processConfigLine(line);        
         //qDebug() << "SetupDialog::slotReadConfigData - in the while" << endl;
     }
-     //qDebug() << "SetupDialog::slotReadConfigData - 3" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData - 3" << endl;
 
     dxClusterPage->setDxclusterServersComboBox(dxClusterServers);
     dxClusterPage->setSelectedDxClusterServer(dxClusterServerToUse);
@@ -674,7 +685,8 @@ bool SetupDialog::processConfigLine(const QString _line)
         value = value.left(value.length() - (value.length() - endValue));
     }
     value = checkAndFixASCIIinADIF(value); // Check whether the value is valid.
-
+    //qDebug() << "SetupDialog::processConfigLine: TAB: " << tab << endl;
+    //qDebug() << "SetupDialog::processConfigLine: VALUE: " << value << endl;
     if (tab == "CALLSIGN"){
          //qDebug() << "SetupDialog::processConfigLine: CALLSIGN: " << value << endl;
         userDataPage->setStationQrz(value);
@@ -857,6 +869,40 @@ bool SetupDialog::processConfigLine(const QString _line)
         colorsPage->setConfirmedColor(value);
     }else if(tab =="DEFAULTCOLOR"){
         colorsPage->setDefaultColor(value);
+        //qDebug() << "SetupDialog::processConfigLine: DEFAULTCOLOR: " << value << endl;
+    }else if(tab =="HAMLIBRIGTYPE"){
+        //qDebug() << "SetupDialog::processConfigLine: Before HAMLIBRIGTYPE: " << value << endl;
+
+        hamlibPage->setRigType(value);
+        //qDebug() << "SetupDialog::processConfigLine: After HAMLIBRIGTYPE: " << value << endl;
+    }else if(tab =="HAMLIBSERIALPORT"){
+        //qDebug() << "SetupDialog::processConfigLine: HAMLIBSERIALPORT: " << value << endl;
+        hamlibPage->setSerialPort(value);
+    }else if(tab =="HAMLIBSERIALBAUDS"){
+        //qDebug() << "SetupDialog::processConfigLine: HAMLIBSERIALBAUDS: " << value << endl;
+        hamlibPage->setSerialSpeed(value);
+    }else if(tab =="HAMLIB"){
+        //qDebug() << "SetupDialog::processConfigLine: HAMLIB: " << value << endl;
+        hamlibPage->setActive(value);
+    }else if(tab =="HAMLIBSERIALDATABITS"){
+        //qDebug() << "SetupDialog::processConfigLine: HAMLIBSERIALDATABITS: " << value << endl;
+        hamlibPage->setDataBits(value);
+    }else if(tab =="HAMLIBSERIALSTOPBITS"){
+        //qDebug() << "SetupDialog::processConfigLine: HAMLIBSERIALSTOPBITS: " << value << endl;
+        hamlibPage->setStopBits(value);
+    }else if(tab =="HAMLIBSERIALFLOWCONTROL"){
+        //qDebug() << "SetupDialog::processConfigLine: HAMLIBSERIALFLOWCONTROL: " << value << endl;
+        hamlibPage->setFlowControl(value);
+    }else if(tab =="HAMLIBSERIALPARITY"){
+        //qDebug() << "SetupDialog::processConfigLine: HAMLIBSERIALPARITY: " << value << endl;
+        hamlibPage->setParity(value);
+    }else if(tab =="HAMLIBSERIALRTS"){
+        //qDebug() << "SetupDialog::processConfigLine: HAMLIBSERIALRTS: " << value << endl;
+        //hamlibPage->setRTS(value);
+    }else if(tab =="HAMLIBSERIALDTR"){
+        //qDebug() << "SetupDialog::processConfigLine: HAMLIBSERIALDTR: " << value << endl;
+        //hamlibPage->setDTR(value);
+
     }else if(tab =="SELECTEDLOG"){
          //qDebug() << "SetupDialog::processConfigLine: SELECTEDLOG: " << value << endl;
         i = value.toInt();
