@@ -29,7 +29,7 @@
 #include "setuppagelogs.h"
 
 SetupPageLogs::SetupPageLogs(DataProxy *dp, QWidget *parent) : QWidget(parent){
-    //qDebug() << "SetupPageLogs::SetupPageLogs" << endl;
+     //qDebug() << "SetupPageLogs::SetupPageLogs" << endl;
     dataProxy = dp;
     stationCallsign = QString();
     operators = QString();
@@ -72,14 +72,14 @@ SetupPageLogs::SetupPageLogs(DataProxy *dp, QWidget *parent) : QWidget(parent){
     removePushButton = new QPushButton(tr("&Remove"), this);
 
 
-    newLogPushButton->setToolTip(tr("Add a new log"));
+    newLogPushButton->setToolTip(tr("Add a new log."));
     //loadAllPushButton->setToolTip(tr("Load all the logs"));
     //loadSelectedPushButton->setToolTip(tr("Load only the selected log"));
     //clearPushButton->setToolTip(tr("Clear selection"));
-    editPushButton->setToolTip(tr("Edit the selected log"));
-    removePushButton->setToolTip(tr("Remove the selected log"));
+    editPushButton->setToolTip(tr("Edit the selected log."));
+    removePushButton->setToolTip(tr("Remove the selected log."));
 
-    currentLogs->setToolTip(tr("Select the log you want to open"));
+    currentLogs->setToolTip(tr("Select the log you want to open."));
 
     QHBoxLayout *buttonsLayout = new QHBoxLayout;
     buttonsLayout->addWidget(newLogPushButton);
@@ -106,17 +106,17 @@ SetupPageLogs::SetupPageLogs(DataProxy *dp, QWidget *parent) : QWidget(parent){
     updateSelectedLogs();
 
 
-    //qDebug() << "SetupPageLogs::SetupPageLogs - END" << endl;
+     //qDebug() << "SetupPageLogs::SetupPageLogs - END" << endl;
 }
 
 SetupPageLogs::~SetupPageLogs(){
-    //qDebug() << "SetupPageLogs::~SetupPageLogs" << endl;
+     //qDebug() << "SetupPageLogs::~SetupPageLogs" << endl;
 }
 
 
 void SetupPageLogs::createNewLog()
 {
-   //qDebug() << "SetupPageLogs::createNewLog" << endl;
+    //qDebug() << "SetupPageLogs::createNewLog" << endl;
     selectedLog = -1;
     //newLog->clear();
     newLog->setEditing(false);
@@ -136,14 +136,14 @@ void SetupPageLogs::createNewLog()
 
 void SetupPageLogs::slotNewButtonClicked()
 {
-    //qDebug() << "SetupPageLogs::slotNewButtonClicked" << endl;
+     //qDebug() << "SetupPageLogs::slotNewButtonClicked" << endl;
 
     createNewLog();
 }
 
 void SetupPageLogs::slotEditButtonClicked()
 {
-    //qDebug() << "SetupPageLogs::slotEditButtonClicked" << endl;
+     //qDebug() << "SetupPageLogs::slotEditButtonClicked" << endl;
     //QSqlQuery query;
     //int nameCol = -1;
 
@@ -160,19 +160,19 @@ void SetupPageLogs::slotEditButtonClicked()
     newLog->setTypeN(dataProxy->getLogTypeNFromLog(selectedLog).toInt());
 
 /*
-    //qDebug() << "SetupPageLogs::slotEditButtonClicked-1 (selectedlog: " << QString::number(selectedLog) << ")" << endl;
+     //qDebug() << "SetupPageLogs::slotEditButtonClicked-1 (selectedlog: " << QString::number(selectedLog) << ")" << endl;
     QString stringQuery = QString("SELECT * FROM logs WHERE id='%1'").arg(selectedLog);
-    //qDebug() << "SetupPageLogs::slotEditButtonClicked -2" << endl;
+     //qDebug() << "SetupPageLogs::slotEditButtonClicked -2" << endl;
 
     bool sqlOk = query.exec(stringQuery);
     QSqlRecord rec = query.record();
     if (sqlOk)
     {
-        //qDebug() << "SetupPageLogs::slotEditButtonClicked Query OK" << endl;
+         //qDebug() << "SetupPageLogs::slotEditButtonClicked Query OK" << endl;
         QSqlRecord rec = query.record();
         if ( (query.next()) && (query.isValid()) )
         {//id/logdate/stationcall/comment/logtype/logtypeid
-            //qDebug() << "SetupPageLogs::slotEditButtonClicked Query Valid" << endl;
+             //qDebug() << "SetupPageLogs::slotEditButtonClicked Query Valid" << endl;
 
 
 
@@ -191,7 +191,7 @@ void SetupPageLogs::slotEditButtonClicked()
             //newLog->setDateString((query.value(nameCol)).toString());
 
             //nameCol = rec.indexOf("logtypen");
-            //qDebug() << "SetupPageLogs::slotEditButtonClicked -3" << endl;
+             //qDebug() << "SetupPageLogs::slotEditButtonClicked -3" << endl;
             //newLog->setTypeN((query.value(nameCol)).toInt());
 
             newLog->exec();
@@ -212,7 +212,7 @@ void SetupPageLogs::slotLogsCancelled(const bool _q)
 
 void SetupPageLogs::slotRemoveButtonClicked()
 {
-    //qDebug() << "SetupPageLogs::slotRemoveButtonClicked" << endl;
+     //qDebug() << "SetupPageLogs::slotRemoveButtonClicked" << endl;
     int selectedLog = getSelectedLog();
 
     QMessageBox::StandardButton ret;
@@ -222,50 +222,50 @@ void SetupPageLogs::slotRemoveButtonClicked()
              QMessageBox::Yes | QMessageBox::No);
     if (ret == QMessageBox::Yes)
     {
-        //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (selected log to remove: " << QString::number(selectedLog) << ")" << endl;
+         //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (selected log to remove: " << QString::number(selectedLog) << ")" << endl;
         QString stringQuery = QString("DELETE FROM logs WHERE id='%1'").arg(selectedLog);
         QSqlQuery query(stringQuery);
 
         bool sqlOk = query.exec();
         if (sqlOk)
         {
-            //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (REMOVED: " << QString::number(selectedLog) << ")" << endl;
+             //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (REMOVED: " << QString::number(selectedLog) << ")" << endl;
             logsModel->select();
             updateSelectedLogs();
             stringQuery = QString("DELETE FROM log WHERE lognumber='%1'").arg(selectedLog);
             query.exec(stringQuery);
             sqlOk = query.exec();
-            //qDebug() << "SetupPageLogs::slotRemoveButtonClicked: LastQuery: " << query.lastQuery()  << endl;
+             //qDebug() << "SetupPageLogs::slotRemoveButtonClicked: LastQuery: " << query.lastQuery()  << endl;
             if (sqlOk)
             {
-                //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (QSOS REMOVED: " << QString::number(selectedLog) << ")" << endl;
+                 //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (QSOS REMOVED: " << QString::number(selectedLog) << ")" << endl;
                 stringQuery = QString("DELETE FROM awarddxcc WHERE lognumber='%2'").arg(selectedLog);
                 query.exec(stringQuery);
                 sqlOk = query.exec();
-                //qDebug() << "SetupPageLogs::slotRemoveButtonClicked: LastQuery: " << query.lastQuery()  << endl;
+                 //qDebug() << "SetupPageLogs::slotRemoveButtonClicked: LastQuery: " << query.lastQuery()  << endl;
                 if (sqlOk)
                 {
-                    //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (AWARDDXCC REMOVED: " << QString::number(selectedLog) << ")" << endl;
+                     //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (AWARDDXCC REMOVED: " << QString::number(selectedLog) << ")" << endl;
                 }
                 else
                 {
                     emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
                     showError(tr("Log has not been removed. (#3)"));
-                    //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (AWARDDXCC NOT REMOVED: " << QString::number(selectedLog) << ")" << endl;
+                     //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (AWARDDXCC NOT REMOVED: " << QString::number(selectedLog) << ")" << endl;
                 }
 
             }
             else
             {
                 showError(tr("Log has not been removed. (#2)"));
-                //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (QSOS NOT REMOVED: " << QString::number(selectedLog) << ")" << endl;
+                 //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (QSOS NOT REMOVED: " << QString::number(selectedLog) << ")" << endl;
             }
         }
         else
         {
             emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().number(), query.lastQuery());
             showError(tr("Log has not been removed. (#1)"));
-            //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (NOT REMOVED: " << QString::number(selectedLog) << ")" << endl;
+             //qDebug() << "SetupPageLogs::slotRemoveButtonClicked (NOT REMOVED: " << QString::number(selectedLog) << ")" << endl;
         }
     }
 
@@ -277,7 +277,7 @@ void SetupPageLogs::slotRemoveButtonClicked()
 
 void SetupPageLogs::createLogsPanel()
 {
-    //qDebug() << "SetupPageLogs::createLogsPanel" << endl;
+     //qDebug() << "SetupPageLogs::createLogsPanel" << endl;
     logsView->setModel(logsModel);
     QString stringQuery = QString("SELECT * FROM logs");
     QSqlQuery query(stringQuery);
@@ -311,7 +311,7 @@ void SetupPageLogs::createLogsPanel()
 
 void SetupPageLogs::createLogsModel()
 {
-    //qDebug() << "SetupPageLogs::createLogsModel" << endl;
+     //qDebug() << "SetupPageLogs::createLogsModel" << endl;
 
         QString stringQuery = QString("SELECT * FROM logs");
         QSqlQuery q(stringQuery);
@@ -346,7 +346,7 @@ void SetupPageLogs::createLogsModel()
 
 void SetupPageLogs::slotLogSelected(const QModelIndex & index)
 {
-    //qDebug() << "SetupPageLogs::slotLogSelected"  << endl;
+     //qDebug() << "SetupPageLogs::slotLogSelected"  << endl;
     int row = index.row();
     setSelectedLog((logsModel->index(row, 0)).data(0).toInt());
 
@@ -354,7 +354,7 @@ void SetupPageLogs::slotLogSelected(const QModelIndex & index)
 
 void SetupPageLogs::slotLogDoubleClicked(const QModelIndex & index)
 {
-    //qDebug() << "SetupPageLogs::slotLogDoubleClicked"  << endl;
+     //qDebug() << "SetupPageLogs::slotLogDoubleClicked"  << endl;
 
     int row = index.row();
     setSelectedLog((logsModel->index(row, 0)).data(0).toInt());
@@ -364,7 +364,7 @@ void SetupPageLogs::slotLogDoubleClicked(const QModelIndex & index)
 
 void SetupPageLogs::createActions()
 {
-    //qDebug() << "SetupPageLogs::createActions" << endl;
+     //qDebug() << "SetupPageLogs::createActions" << endl;
     connect(newLogPushButton, SIGNAL(clicked ( )), this, SLOT(slotNewButtonClicked() ) );
     connect(removePushButton, SIGNAL(clicked ( )), this, SLOT(slotRemoveButtonClicked() ) );
     connect(editPushButton, SIGNAL(clicked ( )), this, SLOT(slotEditButtonClicked() ) );
@@ -381,7 +381,7 @@ void SetupPageLogs::createActions()
 
 QStringList SetupPageLogs::readLogs()
 {
-    //qDebug() << "SetupPageLogs::readLogs" << endl;
+     //qDebug() << "SetupPageLogs::readLogs" << endl;
 
     QString aux, aux2;
     QStringList _logs;
@@ -434,7 +434,7 @@ QStringList SetupPageLogs::readLogs()
 
 
     _logs.clear();
-    //qDebug() << "SetupPageLogs::readLogs: " << QString::number(_logs.size())<< endl;
+     //qDebug() << "SetupPageLogs::readLogs: " << QString::number(_logs.size())<< endl;
 
     return _logs;
 
@@ -443,7 +443,7 @@ QStringList SetupPageLogs::readLogs()
 
 void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
 {
-    //qDebug() << "SetupPageLogs::slotAnalyzeNewLogData (length=" << QString::number(_qs.length()) << ")" << endl;
+     //qDebug() << "SetupPageLogs::slotAnalyzeNewLogData (length=" << QString::number(_qs.length()) << ")" << endl;
 
 
     if (_qs.length()!=14)
@@ -525,7 +525,7 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
 /*
 bool SetupPageLogs::addNewLog(const QStringList _qs)
 {
-    //qDebug() << "SetupPageLogs::addNewLog: " << _qs.at(2) << endl;
+     //qDebug() << "SetupPageLogs::addNewLog: " << _qs.at(2) << endl;
     QString aux = QString();
     int nameCol = -1;
 
@@ -539,7 +539,7 @@ bool SetupPageLogs::addNewLog(const QStringList _qs)
     QString queryString = QString("SELECT * FROM logs WHERE logdate='%1' AND stationcall='%2' AND logtype='%3' AND logtypen='%4'").arg(_dateString).arg(_stationCallsign).arg(_typeContest).arg(_typeContestN);
     //"logs"
     //"id, logdate, stationcall, comment, logtype"
-    //qDebug() << "SetupPageLogs::addNewLog query1: " << queryString << endl;
+     //qDebug() << "SetupPageLogs::addNewLog query1: " << queryString << endl;
     QSqlQuery query;
 
     bool sqlOK = query.exec(queryString);
@@ -549,16 +549,16 @@ bool SetupPageLogs::addNewLog(const QStringList _qs)
     {
         nameCol = rec.indexOf("id");
         aux = (query.value(nameCol)).toString();
-        //qDebug() << "SetupPageLogs::addNewLog: id = " << aux << endl;
+         //qDebug() << "SetupPageLogs::addNewLog: id = " << aux << endl;
         return false;
     }
     queryString = QString("INSERT INTO logs (logdate, stationcall, comment, logtype, logtypen) values('%1','%2','%3','%4', '%5')").arg(_dateString).arg(_stationCallsign).arg(_comment).arg(_typeContest).arg(_typeContestN);
 
-    //qDebug() << "SetupPageLogs::addNewLog query1: " << queryString << endl;
+     //qDebug() << "SetupPageLogs::addNewLog query1: " << queryString << endl;
     sqlOK = query.exec(queryString);
     if (sqlOK)
     {
-        //qDebug() << "SetupPageLogs::addNewLog ADDED! id = "  << endl;
+         //qDebug() << "SetupPageLogs::addNewLog ADDED! id = "  << endl;
         logsModel->select();
         updateSelectedLogs();
         return true;
@@ -572,7 +572,7 @@ bool SetupPageLogs::addNewLog(const QStringList _qs)
 */
 void SetupPageLogs::updateSelectedLogs()
 {
-    //qDebug() << "SetupPageLogs::updateSelectedLogs" << endl;
+     //qDebug() << "SetupPageLogs::updateSelectedLogs" << endl;
     logsAvailable = readLogs();
 
     if (logsAvailable.length()>0)
@@ -582,14 +582,14 @@ void SetupPageLogs::updateSelectedLogs()
     }
     else
     {
-        //qDebug() << "SetupPageLogs::updateSelectedLogs Not selected (less than 1)" << endl;
+         //qDebug() << "SetupPageLogs::updateSelectedLogs Not selected (less than 1)" << endl;
         currentLogs->clear();
     }
 }
 
 int SetupPageLogs::getSelectedLog()
 {
-   //qDebug() << "SetupPageLogs::getSelectedLog: " << currentLogs->currentText() << endl;
+    //qDebug() << "SetupPageLogs::getSelectedLog: " << currentLogs->currentText() << endl;
     QString selectedLog = currentLogs->currentText();
     int i = 0;
     QStringList qs;
@@ -609,18 +609,18 @@ int SetupPageLogs::getSelectedLog()
 
 void SetupPageLogs::setSelectedLog(const int _i)
 {
-    //qDebug() << "SetupPageLogs::SetupPageLogs::setSelectedLog: " << QString::number(_i) << endl;
+     //qDebug() << "SetupPageLogs::SetupPageLogs::setSelectedLog: " << QString::number(_i) << endl;
 
     QString n = QString::number(_i) + "--";
     int selected = currentLogs->findText(n, Qt::MatchStartsWith);
     if (selected >= 0)
     {
-        //qDebug() << "SetupPageLogs::SetupPageLogs::setSelectedLog selected>0: " << QString::number(selected) << endl;
+         //qDebug() << "SetupPageLogs::SetupPageLogs::setSelectedLog selected>0: " << QString::number(selected) << endl;
         currentLogs->setCurrentIndex(selected);
     }
     else
     {
-        //qDebug() << "SetupPageLogs::SetupPageLogs::setSelectedLog not selcted" << endl;
+         //qDebug() << "SetupPageLogs::SetupPageLogs::setSelectedLog not selcted" << endl;
         return;
     }
 }
@@ -657,13 +657,13 @@ void SetupPageLogs::showError(const QString _errorC)
 
 void SetupPageLogs::setDefaultStationCallsign(const QString _p)
 {
-    //qDebug() << "SetupPageLogs::setDefaultStationCallsign: " << _p << endl;
+     //qDebug() << "SetupPageLogs::setDefaultStationCallsign: " << _p << endl;
     defaultStationCallSign = _p;
 }
 
 void SetupPageLogs::setDefaultOperators(const QString _p)
 {
-    //qDebug() << "SetupPageLogs::setDefaultOperators: " << _p << endl;
+     //qDebug() << "SetupPageLogs::setDefaultOperators: " << _p << endl;
     defaultOperators = _p;
 
 }
