@@ -32,7 +32,7 @@
 
 SetupPageLogsNew::SetupPageLogsNew(DataProxy *dp, QWidget *parent)
 {
-    //qDebug() << "SetupPageLogsNew::SetupPageLogsNew"   << endl;
+     //qDebug() << "SetupPageLogsNew::SetupPageLogsNew"   << endl;
     dataProxy = dp;
     editing = false;
     checking = false;
@@ -101,7 +101,7 @@ SetupPageLogsNew::SetupPageLogsNew(DataProxy *dp, QWidget *parent)
 
     okButton->setEnabled(false);
 
-    //qDebug() << "SetupPageLogsNew::SetupPageLogsNew - END"   << endl;
+     //qDebug() << "SetupPageLogsNew::SetupPageLogsNew - END"   << endl;
 }
 
 void SetupPageLogsNew::clear()
@@ -134,7 +134,7 @@ void SetupPageLogsNew::clear()
 
 void SetupPageLogsNew::createWidget()
 {
-    //qDebug() << "SetupPageLogsNew::createWidget" << endl;
+     //qDebug() << "SetupPageLogsNew::createWidget" << endl;
 
     stationCallsignLabel->setWordWrap(true);
     operatorsLabel->setWordWrap(true);
@@ -156,11 +156,11 @@ void SetupPageLogsNew::createWidget()
     validCats->setWordWrap(true);
 
 
-    stationCallsignLineEdit->setToolTip(tr("Callsign used for this log"));
-    operatorsLineEdit->setToolTip(tr("Comma separated list of operators: callsign1, callsign2"));
+    stationCallsignLineEdit->setToolTip(tr("Callsign used for this log."));
+    operatorsLineEdit->setToolTip(tr("Comma separated list of operators: callsign1, callsign2."));
 
-    dateEdit->setToolTip(tr("Start date of this log"));
-    commentLineEdit->setToolTip(tr("Add a comment about this log"));
+    dateEdit->setToolTip(tr("Start date of this log."));
+    commentLineEdit->setToolTip(tr("Add a comment about this log."));
 
     typeLabel->setText(tr("&Type of Operation"));
     typeLabel->setWordWrap(true);
@@ -169,16 +169,16 @@ void SetupPageLogsNew::createWidget()
     dateLabel->setWordWrap(true);
 
 
-    typeComboBox->setToolTip(tr("Select the kind of operation for this log"));
+    typeComboBox->setToolTip(tr("Select the kind of operation for this log."));
     QStringList _qs;
     _qs.clear();
     _qs.append(dataProxy->getContestNames());    
     typeComboBox->addItems(_qs);
-    //qDebug() << "SetupPageLogsNew::createWidget - contestNames: " << _qs.at(0) << endl;
+     //qDebug() << "SetupPageLogsNew::createWidget - contestNames: " << _qs.at(0) << endl;
 
     catModeLabel->setText(tr("&Mode Category"));
     catModeLabel->setWordWrap(true);
-    contestCatModeComboBox->setToolTip(tr("Select the mode category"));
+    contestCatModeComboBox->setToolTip(tr("Select the mode category."));
     _qs.clear();
     _qs.append(dataProxy->getContestCat(6));
     contestCatModeComboBox->addItems(_qs);
@@ -186,14 +186,14 @@ void SetupPageLogsNew::createWidget()
     //QLabel *catOpLabel = new QLabel(tr("Operators Category"));
     catOpLabel->setText(tr("O&perators Category"));
     catOpLabel->setWordWrap(true);
-    contestCatOperatorsComboBox->setToolTip(tr("Select the operators category"));
+    contestCatOperatorsComboBox->setToolTip(tr("Select the operators category."));
     _qs.clear();
     _qs.append(dataProxy->getContestCat(1));
     contestCatOperatorsComboBox->addItems(_qs);
 
     catAsLabel->setText(tr("&Assisted Category"));
     catOpLabel->setWordWrap(true);
-    contestCatAssistedComboBox->setToolTip(tr("Select the assisted category"));
+    contestCatAssistedComboBox->setToolTip(tr("Select the assisted category."));
     _qs.clear();
     _qs.append(dataProxy->getContestCat(2));
     contestCatAssistedComboBox->addItems(_qs);
@@ -201,7 +201,7 @@ void SetupPageLogsNew::createWidget()
     //QLabel *catPowerLabel = new QLabel(tr("Power Category"));
     catPowerLabel->setText(tr("Po&wer Category"));
     catPowerLabel->setWordWrap(true);
-    contestCatPowerComboBox->setToolTip(tr("Select the power category"));
+    contestCatPowerComboBox->setToolTip(tr("Select the power category."));
     _qs.clear();
     _qs.append(dataProxy->getContestCat(3));
     contestCatPowerComboBox->addItems(_qs);
@@ -209,14 +209,14 @@ void SetupPageLogsNew::createWidget()
     //QLabel *catBandsLabel = new QLabel(tr("Bands Category"));
     catBandsLabel->setText(tr("&Bands Category"));
     catBandsLabel->setWordWrap(true);
-    contestCatBandsComboBox->setToolTip(tr("Select the bands category"));
+    contestCatBandsComboBox->setToolTip(tr("Select the bands category."));
     _qs.clear();
     _qs.append(dataProxy->getContestCat(4));
     contestCatBandsComboBox->addItems(_qs);
 
     overlayLabel->setText(tr("O&verlay"));
     overlayLabel->setWordWrap(true);
-    contestCatOverlayComboBox->setToolTip(tr("Select the Overlay category"));
+    contestCatOverlayComboBox->setToolTip(tr("Select the Overlay category."));
     _qs.clear();
     _qs.append(dataProxy->getContestOverlays());
     contestCatOverlayComboBox->addItems(_qs);
@@ -298,7 +298,7 @@ void SetupPageLogsNew::createWidget()
 
 void SetupPageLogsNew::slotOperatorsTextChanged()
 {
-    //qDebug() << "SetupPageLogsNew::slotOperatorsTextChanged" << endl;
+     //qDebug() << "SetupPageLogsNew::slotOperatorsTextChanged" << endl;
 //    connect(stationCallsignLineEdit, SIGNAL(textChanged(QString)), this, SLOT( ) );
     if ((operatorsLineEdit->text()).length()<1)
     {
@@ -328,7 +328,7 @@ void SetupPageLogsNew::slotOperatorsTextChanged()
 
 void SetupPageLogsNew::slotStationCallSignTextChanged()
 {
-    //qDebug() << "SetupPageLogsNew::slotStationCallSignTextChanged" << endl;
+     //qDebug() << "SetupPageLogsNew::slotStationCallSignTextChanged" << endl;
 //    connect(stationCallsignLineEdit, SIGNAL(textChanged(QString)), this, SLOT( ) );
     if ((stationCallsignLineEdit->text()).length()<1)
     {
@@ -360,7 +360,7 @@ void SetupPageLogsNew::slotStationCallSignTextChanged()
 
 void SetupPageLogsNew::slotTypeComboBoxChanged()
 {
-    //qDebug() << "SetupPageLogsNew::slotTypeComboBoxChanged" << endl;
+     //qDebug() << "SetupPageLogsNew::slotTypeComboBoxChanged" << endl;
 //    connect(typeComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotTypeComboBoxChanged() ) ) ;
 
 
@@ -392,7 +392,7 @@ void SetupPageLogsNew::slotTypeComboBoxChanged()
 
 void SetupPageLogsNew::slotCatAssistedComboBoxChanged()
 {
-   //qDebug() << "SetupPageLogs:slotCatAssistedComboBoxChanged: " << QString::number(contestCatAssistedComboBox->currentIndex())  << endl;
+    //qDebug() << "SetupPageLogs:slotCatAssistedComboBoxChanged: " << QString::number(contestCatAssistedComboBox->currentIndex())  << endl;
 //connect(contestCatAssistedComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotCatAssistedComboBoxChanged() ) ) ;
 
    contestCatMode = contestCatModeComboBox->currentIndex();
@@ -420,7 +420,7 @@ void SetupPageLogsNew::slotCatAssistedComboBoxChanged()
 
 void SetupPageLogsNew::slotCatOperatorsComboBoxChanged()
 {
-   //qDebug() << "SetupPageLogsNew::slotCatOperatorsComboBoxChanged(): " << QString::number(contestCatOperatorsComboBox->currentIndex())  << endl;
+    //qDebug() << "SetupPageLogsNew::slotCatOperatorsComboBoxChanged(): " << QString::number(contestCatOperatorsComboBox->currentIndex())  << endl;
 
    contestCatMode = contestCatModeComboBox->currentIndex();
    contestCatBands = contestCatBandsComboBox->currentIndex();
@@ -447,7 +447,7 @@ void SetupPageLogsNew::slotCatOperatorsComboBoxChanged()
 
 void SetupPageLogsNew::slotCatPowerComboBoxChanged()
 {
-    //qDebug() << "SetupPageLogsNew::slotCatPowerComboBoxChanged(): " << QString::number(contestCatPowerComboBox->currentIndex())  << endl;
+     //qDebug() << "SetupPageLogsNew::slotCatPowerComboBoxChanged(): " << QString::number(contestCatPowerComboBox->currentIndex())  << endl;
 //connect(contestCatPowerComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotCatPowerComboBoxChanged() ) ) ;
 
     contestCatMode = contestCatModeComboBox->currentIndex();
@@ -475,7 +475,7 @@ void SetupPageLogsNew::slotCatPowerComboBoxChanged()
 
 void SetupPageLogsNew::slotCatBandsComboBoxChanged()
 {
-    //qDebug() << "SetupPageLogsNew::slotCatBandsComboBoxChanged(): " << QString::number(contestCatBandsComboBox->currentIndex())  << endl;
+     //qDebug() << "SetupPageLogsNew::slotCatBandsComboBoxChanged(): " << QString::number(contestCatBandsComboBox->currentIndex())  << endl;
 //connect(contestCatBandsComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotCatBandsComboBoxChanged() ) ) ;
 
     contestCatMode = contestCatModeComboBox->currentIndex();
@@ -503,7 +503,7 @@ void SetupPageLogsNew::slotCatBandsComboBoxChanged()
 
 void SetupPageLogsNew::slotBandsComboBoxChanged()
 {
-    //qDebug() << "SetupPageLogsNew::slotBandsComboBoxChanged(): " << QString::number(contestBandsComboBox->currentIndex()) << endl;
+     //qDebug() << "SetupPageLogsNew::slotBandsComboBoxChanged(): " << QString::number(contestBandsComboBox->currentIndex()) << endl;
             //connect(contestBandsComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotBandsComboBoxChanged() ) ) ;
 
 }
@@ -511,7 +511,7 @@ void SetupPageLogsNew::slotBandsComboBoxChanged()
 
 void SetupPageLogsNew::slotCatOverlayComboBoxChanged()
 {
-     //qDebug() << "SetupPageLogsNew::slotCatOverlayComboBoxChanged(): " << QString::number(contestCatOverlayComboBox->currentIndex())  << endl;
+      //qDebug() << "SetupPageLogsNew::slotCatOverlayComboBoxChanged(): " << QString::number(contestCatOverlayComboBox->currentIndex())  << endl;
 
      contestCatMode = contestCatModeComboBox->currentIndex();
      contestCatBands = contestCatBandsComboBox->currentIndex();
@@ -522,7 +522,7 @@ void SetupPageLogsNew::slotCatOverlayComboBoxChanged()
      contestCatOverlay= contestCatOverlayComboBox->currentIndex();
 
      typeContest = getSelectedTypeContest();
-     //qDebug() << "SetupPageLogsNew::slotCatOverlayComboBoxChanged(): typeContest =  " << QString::number(typeContest)  << endl;
+      //qDebug() << "SetupPageLogsNew::slotCatOverlayComboBoxChanged(): typeContest =  " << QString::number(typeContest)  << endl;
 
      if (typeContest < 0)
      {
@@ -539,7 +539,7 @@ void SetupPageLogsNew::slotCatOverlayComboBoxChanged()
 
 void SetupPageLogsNew::slotCatModeComboBoxChanged()
 {
-    //qDebug() << "SetupPageLogsNew::slotCatModeComboBoxChanged(): " << QString::number(contestCatModeComboBox->currentIndex())  << endl;
+     //qDebug() << "SetupPageLogsNew::slotCatModeComboBoxChanged(): " << QString::number(contestCatModeComboBox->currentIndex())  << endl;
 
     contestCatMode = contestCatModeComboBox->currentIndex();
     contestCatBands = contestCatBandsComboBox->currentIndex();
@@ -550,7 +550,7 @@ void SetupPageLogsNew::slotCatModeComboBoxChanged()
     contestCatOverlay= contestCatOverlayComboBox->currentIndex();
 
     typeContest = getSelectedTypeContest();
-    //qDebug() << "SetupPageLogsNew::slotCatModeComboBoxChanged(): " << QString::number(typeContest)  << endl;
+     //qDebug() << "SetupPageLogsNew::slotCatModeComboBoxChanged(): " << QString::number(typeContest)  << endl;
 
     if (typeContest < 0)
     {
@@ -568,7 +568,7 @@ void SetupPageLogsNew::slotCatModeComboBoxChanged()
 void SetupPageLogsNew::slotOKButtonClicked()
 {
 
-    //qDebug() << "SetupPageLogsNew::slotOkButtonClicked" << endl;
+     //qDebug() << "SetupPageLogsNew::slotOkButtonClicked" << endl;
     stationCallsign = stationCallsignLineEdit->text();
     if (stationCallsign.length()<3)
     {
@@ -589,92 +589,92 @@ void SetupPageLogsNew::slotOKButtonClicked()
 
     if (typeComboBox->isEnabled())
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: type" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: type" << endl;
         typeContestSelected = typeComboBox->currentIndex();
         typeConteststr = typeComboBox->currentText();
     }
     else
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: type" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: type" << endl;
         typeContestSelected = 0;
         typeConteststr = QString();
     }
 
     if (contestCatModeComboBox->isEnabled())
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: mode" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: mode" << endl;
         contestCatMode = contestCatModeComboBox->currentIndex();
     }
     else
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: mode" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: mode" << endl;
         contestCatMode = 0;
     }
 
     if (contestCatOperatorsComboBox->isEnabled())
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: oper" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: oper" << endl;
        contestCatOperators = contestCatOperatorsComboBox->currentIndex();
     }
     else
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: oper" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: oper" << endl;
         contestCatOperators = 0;
     }
 
     if (contestCatAssistedComboBox->isEnabled())
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: ass" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: ass" << endl;
         contestCatAssisted = contestCatAssistedComboBox->currentIndex();
     }
     else
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: ass" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: ass" << endl;
         contestCatAssisted = 0;
     }
 
     if (contestCatPowerComboBox->isEnabled())
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: pwr" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: pwr" << endl;
         contestCatPower = contestCatPowerComboBox->currentIndex();
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: pwr - " << contestCatPowerComboBox->currentText() << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: pwr - " << contestCatPowerComboBox->currentText() << endl;
     }
     else
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: pwr" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: pwr" << endl;
          contestCatPower = 0;
     }
 
     if (contestCatBandsComboBox->isEnabled())
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: Cbands" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: Cbands" << endl;
         contestCatBands = contestCatBandsComboBox->currentIndex();
     }
     else
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: Cbands" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: Cbands" << endl;
         contestCatBands = 0;
     }
 
     if (contestBandsComboBox->isEnabled())
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: bands" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: bands" << endl;
         contestBands = contestBandsComboBox->currentIndex();
     }
     else
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: bands" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: bands" << endl;
         contestBands = 0;
     }
 
     if (contestCatOverlayComboBox->isEnabled())
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: over" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked ENA: over" << endl;
         contestCatOverlay = contestCatOverlayComboBox->currentIndex();
     }
     else
     {
-        //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: over" << endl;
+         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: over" << endl;
         contestCatOverlay = 0;
     }
 
@@ -700,7 +700,7 @@ void SetupPageLogsNew::slotOKButtonClicked()
 }
 void SetupPageLogsNew::gatherAndSend()
 {
-     //qDebug() << "SetupPageLogsNew::gatherAndSend: " << typeConteststr << endl;
+      //qDebug() << "SetupPageLogsNew::gatherAndSend: " << typeConteststr << endl;
 
     // The following lines will be removed once more contest types have been added
     contestCatMode = contestCatModeComboBox->currentIndex();
@@ -736,21 +736,18 @@ void SetupPageLogsNew::gatherAndSend()
     {
         logData << "0";
     }
+
     //logData << QString::number(typeContest)
     // Update the SetupPageLogs::slotAnalyzeNewLogData if you add or remove any field (Today 12)
 
-    //for (int i=0;i<logData.length();i++)
-    //{
-    //qDebug() << "SetupPageLogsNew::gatherAndSend: " << logData.at(i) << endl;
-    //}
-    //qDebug() << "SetupPageLogsNew::gatherAndSend: EMITED" << endl;
+     //qDebug() << "SetupPageLogsNew::gatherAndSend: EMITED" << endl;
     emit newLogData(logData);
 
 }
 
 void SetupPageLogsNew::slotCancelButtonClicked()
 {
-    //qDebug() << "SetupPageLogsNew::slotCancelButtonClicked" << endl;
+     //qDebug() << "SetupPageLogsNew::slotCancelButtonClicked" << endl;
     logData.clear();
     emit cancelled(true);
     close();
@@ -768,7 +765,7 @@ QStringList SetupPageLogsNew::getValidCatOptions(const int _currentCat, const in
 // 5 - contestcatoverlay
 // 6 - contestcatmode
 
-    //qDebug() << "SetupPageLogsNew::getValidCatOptions: " << QString::number(_currentCat) <<"/"<< QString::number(_higherCat) << endl;
+     //qDebug() << "SetupPageLogsNew::getValidCatOptions: " << QString::number(_currentCat) <<"/"<< QString::number(_higherCat) << endl;
     //return dataProxy->getValidCatOptions(_currentCat, _higherCat);
     return QStringList();
 }
@@ -863,32 +860,32 @@ void SetupPageLogsNew::setEditing(const bool b)
 
 int SetupPageLogsNew::getSelectedTypeContest()
 {
-    //qDebug() << "SetupPageLogsNew::getSelectedTypeContest: " << endl;
+     //qDebug() << "SetupPageLogsNew::getSelectedTypeContest: " << endl;
     //is/contest/catoperator/catassisted/catpower/catband/catoverlay/catmode
     int i = dataProxy->getContestTypeN(typeContestSelected, contestCatOperators, contestCatAssisted, contestCatPower, contestCatBands, contestCatOverlay, contestCatMode);
-    //qDebug() << "SetupPageLogsNew::getSelectedTypeContest: " << QString::number(i) << endl;
+     //qDebug() << "SetupPageLogsNew::getSelectedTypeContest: " << QString::number(i) << endl;
     return i;
 
 }
 
 void SetupPageLogsNew::setTypeN(const int _n)
 {
-    //qDebug() << "SetupPageLogsNew::setTypeN: " << QString::number(_n) << endl;
+     //qDebug() << "SetupPageLogsNew::setTypeN: " << QString::number(_n) << endl;
     typeContestSelected = _n;
     fillWithType(typeContestSelected);
 }
 
 void SetupPageLogsNew::fillWithType(const int _n)
 {
-    //qDebug() << "SetupPageLogsNew::fillWithType - n = " << QString::number(_n) << endl;
+     //qDebug() << "SetupPageLogsNew::fillWithType - n = " << QString::number(_n) << endl;
     typeContestSelected = _n;
     QStringList contestData;
     contestData << dataProxy->getDataFromContestType(_n);
-    //qDebug() << "SetupPageLogsNew::fillWithType-1 (length = " << QString::number(contestData.length()) << ")" << endl;
+     //qDebug() << "SetupPageLogsNew::fillWithType-1 (length = " << QString::number(contestData.length()) << ")" << endl;
     if (contestData.length()== 8)
     {
 
-        //qDebug() << "SetupPageLogsNew::fillWithType-2" << endl;
+         //qDebug() << "SetupPageLogsNew::fillWithType-2" << endl;
         setCOperators ((contestData.at(1)).toInt());
         setCAssisted ((contestData.at(2)).toInt());
         setCPower ((contestData.at(3)).toInt());
@@ -896,11 +893,11 @@ void SetupPageLogsNew::fillWithType(const int _n)
         setCMode ((contestData.at(5)).toInt());
         setType(contestData.at(6));
         setCBands((contestData.at(7)).toInt());
-        //qDebug() << "SetupPageLogsNew::fillWithType: " << contestData.at(6) << endl;
+         //qDebug() << "SetupPageLogsNew::fillWithType: " << contestData.at(6) << endl;
     }
     else
     {
-        //qDebug() << "SetupPageLogsNew::fillWithType-3" << endl;
+         //qDebug() << "SetupPageLogsNew::fillWithType-3" << endl;
         return;
     }
 
@@ -908,7 +905,7 @@ void SetupPageLogsNew::fillWithType(const int _n)
 
 void SetupPageLogsNew::updateAllCats()
 {
-    //qDebug() << "SetupPageLogsNew::updateAllCats" << endl;
+     //qDebug() << "SetupPageLogsNew::updateAllCats" << endl;
 
     contestCatMode = contestCatModeComboBox->currentIndex();
     contestCatBands = contestCatBandsComboBox->currentIndex();
