@@ -5,6 +5,7 @@ StatisticsWidget::StatisticsWidget(DataProxy *dp, QWidget *parent): QWidget(pare
 
     dataProxy = dp;
     statisticToShowComboBox = new QComboBox();
+    logComboBox = new QComboBox();
     barChartStats = new BarChartStats(dp, this);
     //donutChartStats = new DonutChartStats(dp, this);
 
@@ -15,10 +16,13 @@ StatisticsWidget::StatisticsWidget(DataProxy *dp, QWidget *parent): QWidget(pare
 
     createUI();
     connect(statisticToShowComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotChartComboBoxChanged() ) ) ;
+    connect(logComboBox, SIGNAL(currentIndexChanged ( int)), this, SLOT(slotLogComboBoxChanged() ) ) ;
+
     barChartStats->prepareChart(1);
 
 }
 
+
 StatisticsWidget::~StatisticsWidget()
 {
 
@@ -40,22 +44,37 @@ void StatisticsWidget::showEvent(QShowEvent *event)
 {
     //qDebug() << "StatisticsWidget::showEvent" << endl;
     barChartStats->clear();
+    fillLogCombo();
     event->accept();
 }
 
 void StatisticsWidget::slotChartComboBoxChanged()
 {    
      //qDebug() << "StatisticsWidget::slotChartComboBoxChanged: " << statisticToShowComboBox->currentText()  << endl;
-    QString text = statisticToShowComboBox->currentText();
-    text.truncate(2);
+    //QString text = statisticToShowComboBox->currentText();
+    //text.truncate(2);
      //qDebug() << "StatisticsWidget::slotChartComboBoxChanged: SelectedGrapth:  " << text << endl;
 
-    barChartStats->prepareChart(text.toInt());
-
+    //barChartStats->prepareChart(text.toInt());
+    updateChart();
     statisticToShowComboBox->setFocus();
 }
 
- void StatisticsWidget::createUI()
+void StatisticsWidget::slotLogComboBoxChanged()
+{
+
+}
+
+void StatisticsWidget::updateChart()
+{
+    QString text = statisticToShowComboBox->currentText();
+    text.truncate(2);
+    int log = ((logComboBox->currentText()).left((logComboBox->currentText()).indexOf('-')+1)).toInt();
+
+    barChartStats->prepareChart(text.toInt(), log);
+}
+
+void StatisticsWidget::createUI()
  {
      statisticsToShowList << "01-" + tr("QSO per year");
      statisticsToShowList << "02-" + tr("DXCC per year");
@@ -72,12 +91,50 @@ void StatisticsWidget::slotChartComboBoxChanged()
 
      statisticToShowComboBox->addItems(statisticsToShowList);
 
+    fillLogCombo();
+
+     QHBoxLayout *hLayout = new QHBoxLayout;
+     hLayout->addWidget(statisticToShowComboBox);
+     hLayout->addWidget(logComboBox);
 
      QVBoxLayout *layout = new QVBoxLayout;
-     layout->addWidget(statisticToShowComboBox);
+     layout->addLayout(hLayout);
+     //layout->addWidget(statisticToShowComboBox);
      //layout->addWidget(graphWidget);
      layout->addWidget(barChartStats);
      setLayout(layout);
      resize(420,300);
 
  }
+
+void StatisticsWidget::fillLogCombo()
+{
+    QStringList ids;
+    ids.clear();
+    ids << dataProxy->getListOfManagedLogs();
+    QStringList logs;
+    logs.clear();
+
+    for (int i = 0; i < ids.size(); ++i)
+    {
+        //cout << fonts.at(i).toLocal8Bit().constData() << endl;
+        logs<< ids.at(i) + "-" + dataProxy->getLogDateFromLog((ids.at(i)).toInt()) + "-" + dataProxy->getStationCallSignFromLog((ids.at(i)).toInt());
+    }
+    logComboBox->clear();
+    logComboBox->addItems(logs);
+
+/*
+    QStringList getListOfManagedLogs();
+    int getMaxLogNumber();
+    QString getStationCallSignFromLog(const int _log);
+    QStringList getStationCallSignsFromLog(const int _log);
+    QString getOperatorsFromLog(const int _log);
+    QString getCommentsFromLog(const int _log);
+    QString getLogDateFromLog(const int _log);
+    QString getLogTypeNFromLog(const int _log);
+    bool addNewLog (const QStringList _qs);
+    bool doesThisLogExist(const int _log);
+
+
+*/
+}
